@@ -1,30 +1,21 @@
 import json
-import os
 from copy import copy
 
 from django.conf import settings
 from django.test import TestCase
 
-from scan_models.main import scan_model
 from scan_models.settings import DEFAULT_SETTINGS
-from scan_models.tests.constances import standard_output
+from scan_models.tests.constances import standard_output, create_test
 
 
 class TestHappyFlow(TestCase):
+    maxDiff = None
+
     def setUp(self) -> None:
         settings.SCAN_MODELS = copy(DEFAULT_SETTINGS)
 
-    def create_test(self):
-        path = "./output.json"
-        scan_model("tests.TestModel", path)
-
-        file = open(os.path.abspath(path), "r")
-        data = json.load(file)
-
-        return data
-
     def test_happy_flow(self):
-        data = self.create_test()
+        data = create_test("tests.TestModel")
         self.assertEqual(data, standard_output)
 
     def test_camelize(self):
@@ -33,6 +24,7 @@ class TestHappyFlow(TestCase):
 
         output["maxAmount"] = output.pop("max_amount")
         output["minAmount"] = output.pop("min_amount")
+        output["aOrB"] = output.pop("a_or_b")
 
-        data = self.create_test()
+        data = create_test("tests.TestModel")
         self.assertEqual(data, output)
